/**********************************************************************************/
/*                                                                                */
/*                                                                                */
/* Program                                                                        */
/* =======                                                                        */
/*                                                                                */
/* mkknot1.c                                                                      */
/*                                                                                */
/*                                                                                */
/* Purpose                                                                        */
/* =======                                                                        */
/*                                                                                */
/* To make POVRAY code for a trefoil knot curve (see the files knot1*.pov).       */
/* The generated code should be pasted into a POVRAY "sphere_sweep" object.       */
/*                                                                                */
/*                                                                                */
/* Version 1.00                                                                   */
/* ============                                                                   */
/*                                                                                */
/* First version: 2006-10-01                                                      */
/* Latest update: 2006-12-08                                                      */
/*                                                                                */
/*                                                                                */
/* Author of the program                                                          */
/* =====================                                                          */
/*                                                                                */
/* Stefan Spaennare, Lund, Sweden                                                 */
/*                                                                                */
/* E-mail: stefan@spaennare.se                                                    */
/*                                                                                */
/* Home page:   http://www.spaennare.se/index.html                                */
/*                                                                                */
/* POVRAY page: http://www.spaennare.se/povray.html                               */
/*                                                                                */
/*                                                                                */
/* Usage                                                                          */
/* =====                                                                          */
/*                                                                                */
/* Parameters ending with "i" are integers and with "r" are real numbers          */
/* (i.e. double precision).                                                       */
/*                                                                                */
/* These parameters work well to define a typical knot curve:                     */
/* ----------------------------------------------------------                     */
/*                                                                                */
/* >mkknot1 1.1 72 0.8 >kn1.pov                                                   */
/*                                                                                */
/* Explanation of the parameters:                                                 */
/* ------------------------------                                                 */
/*                                                                                */
/* >Usage: mkknot1 wmaxr nwstepsi rr                                              */
/*                                                                                */
/* wmax: Number of complete revolutions (2*pi) the knot is formed.                */
/*                                                                                */
/* nwsteps: Number of steps per complete revolution.                              */
/*                                                                                */
/* r: Knot thickness ("sphere_sweep" radius).                                     */
/*                                                                                */
/*                                                                                */
/* References                                                                     */
/* ==========                                                                     */
/*                                                                                */
/* The knot function is found elsewhere on Internet. See the C-code below.        */
/*                                                                                */
/*                                                                                */
/**********************************************************************************/

/********************************************************************************/
/*                                                                              */
/* Notice                                                                       */
/* ======                                                                       */
/*                                                                              */
/* I make no warranties that this program is (1) free of errors, (2) consistent */
/* with any standard merchantability, or (3) meeting the requirements of a      */
/* particular application. This software shall not, partly or as a whole,       */
/* participate in a process, whose outcome can result in injury to a person or  */
/* loss of property. It is solely designed for analytical work. Permission to   */
/* use, copy and distribute is hereby granted without fee, providing that the   */
/* header above including this notice appears in all copies.                    */
/*                                                                              */
/*                                                            Stefan Spaennare  */
/*                                                                              */
/********************************************************************************/


#include <math.h>
#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <time.h>
#include <string.h>

double timetic=(double)(CLOCKS_PER_SEC);

double pi=3.14159265358979323;


int main(argc,argv)
int argc;
char *argv[];
{

   int nw;

   double w,dw,wmax,wmax0,x,y,z,r,t;


   if (argc != 4) {
      printf("Usage: %s wmaxr nwstepsi rr\n",argv[0]);
      exit(0);
   } /* if */

   wmax0=atof(argv[1]);
   nw=atoi(argv[2]);
   r=atof(argv[3]);

   wmax=2.0*pi*wmax0;
   dw=2.0*pi/(double)(nw);

   w=0.0;

   do {

      t=w;

      x=sin(t)+2.0*sin(2.0*t);
      y=cos(t)-2.0*cos(2.0*t);
      z=sin(3.0*t);

      printf("<%16.12f, %16.12f, %16.12f>, %16.12f\n",-x,y,z,r);

      w=w+dw;

   } while (w <= wmax);


   return(0);

} /* End  */
