//
//
// Pov-file for the POVRAY ray-tracing program 
// ===========================================
//
// Made when: Sometimes during the time 1994 - 1997, updated September 2005
//
// By Stefan Spaennare, Lund, Sweden
//
// E-mail: stefan@spaennare.se
//
// Home page of the author: 
// http://www.spaennare.se/index.html
//
// The image and this pov-file are available on the web-page:
// http://www.spaennare.se/povray.html
//
// This pov-file is free to copy or change if this header appears
// in all copies.
//
// This image is quite "simple" and takes only a few minutes to render
// (at 800 x 600 pixels) on a 1 GHz class computer (or faster).
//
// This pov-file is for POVRAY 3.6 Linux version.
// Use the +mv3.6 option to render with newer versions of POVRAY.
//
// The POVRAY ray-tracing program can be downloaded for free from:
// http://www.povray.org
//
//


#include "colors.inc"
// #include "glass.inc"
// #include "golds.inc"
#include "shapes.inc"
#include "woods.inc"

camera {
   location <0, 5, -30>
   up <0.0, 1.0, 0.0>
   right <4/3, 0.0, 0.0>
   look_at <0, 0, 0>
}

light_source { <9, 10, -40> 
               color rgb 0.30
	       shadowless
}
light_source { <-9, 10, -40> 
               color rgb 0.30
	       shadowless
}
light_source { <0, 40, 0> 
               color rgb 0.30
	       shadowless 
}

light_source { <14, 14, -40> 
               color rgb 0.6
}

sky_sphere { pigment {rgb <0.9,0.9,0.9>} }

#declare wood1 = texture {
   T_Wood11
    scale 8.0
}

plane {y, -7.5
   texture { wood1 }
}

plane {z, 10.0 inverse
   texture { 
      pigment {rgb 0.8}  
      finish {
         phong 0.0
	 phong_size 1.0
	 ambient 0.8
	 diffuse 0.2
      }
   }
}

#declare box1 = box { <-0.5,-0.5,-0.5> <0.5,0.5,0.5> }


#declare frame1 = union {
    object { box1
       scale <1.0, 15.0, 2.0>
       translate -6.5*x
    }
    object { box1
       scale <1.0, 15.0, 2.0>
       translate 6.5*x
    }
    object { box1
       scale <14.0, 1.0, 2.0>
       translate 7.0*y 
    }
    object { box1
       scale <14.0, 1.0, 2.0>
       translate -7.0*y 
    }
//   texture { wood1 }
   texture { wood1 
      rotate 90.0*x
   }
}

#declare cyl1 = object {
    cylinder { -6.5*x, 6.5*x, 0.12 }
texture {
   finish {
      ambient 0.03
      diffuse 1.0
      reflection 0.4
      phong 1.0
      phong_size 3.0
   }
   pigment { color red 0.5 green 0.45 blue 0.35 }
   }
}

#declare colfinish = finish {
         phong 1.0
         phong_size 10.0
         ambient 0.2
         diffuse 0.8
}

/*
#declare colfinish = finish {
   phong 1.0
   phong_size 10.0
   ambient 0.07
   diffuse 3.5 
}
*/

#declare kred = object {
   sphere { <0.0, 0.0, 0.0>, 1.0}
   texture {
      pigment { Red }
      finish { colfinish }
   }
}

#declare kgre = object {
   sphere { <0.0, 0.0, 0.0>, 1.0}
   texture {
      pigment { Green }
      finish { colfinish }
   }
}

#declare kyel = object {
   sphere { <0.0, 0.0, 0.0>, 1.0}
   texture {
      pigment { Yellow }
      finish { colfinish }
   }
}

#declare kblu = object {
   sphere { <0.0, 0.0, 0.0>, 1.0}
   texture {
      pigment { Blue }
      finish { colfinish }
   }
}

#declare abacus = union {

   object { frame1 }

   object { cyl1 translate 4.5*y }
   object { cyl1 translate 1.5*y }
   object { cyl1 translate -1.5*y }
   object { cyl1 translate -4.5*y }

   object { kred translate <-5.0, 4.5, 0.0> }
   object { kred translate <-1.0, 4.5, 0.0> }
   object { kred translate <1.0, 4.5, 0.0> }
   object { kred translate <3.0, 4.5, 0.0> }
   object { kred translate <5.0, 4.5, 0.0> }

   object { kgre translate <-3.0, 1.5, 0.0> }
   object { kgre translate <-1.0, 1.5, 0.0> }
   object { kgre translate <1.0, 1.5, 0.0> }
   object { kgre translate <3.0, 1.5, 0.0> }
   object { kgre translate <5.0, 1.5, 0.0> }

   object { kyel translate <-3.0, -1.5, 0.0> }
   object { kyel translate <-1.0, -1.5, 0.0> }
   object { kyel translate <1.0, -1.5, 0.0> }
   object { kyel translate <3.0, -1.5, 0.0> }
   object { kyel translate <5.0, -1.5, 0.0> }

   object { kblu translate <-3.0, -4.5, 0.0> }
   object { kblu translate <-1.0, -4.5, 0.0> }
   object { kblu translate <1.0, -4.5, 0.0> }
   object { kblu translate <3.0, -4.5, 0.0> }
   object { kblu translate <5.0, -4.5, 0.0> }
}

#declare frame2 = object {
   union {
      object {
         box1
	 scale <14.0, 15.0, 2.0>
      }
      text { ttf "cyrvetic.ttf" "Abacus" 1, 0
	 scale 3.3
	 translate <-5.25, -0.8, -3.0>
      }
   }
//   texture { wood1 }
   texture { wood1 
      rotate 90.0*x
   }

}

object { abacus 
    rotate -25.0*y
    translate -9.0*x
}

object { frame2
    rotate 25.0*y
    translate 9.0*x
}
