//
//
// Pov-file for the POVRAY ray-tracing program 
// ===========================================
//
// Made when: May 1996, updated September 2005
//
// By Stefan Spaennare, Lund, Sweden
//
// E-mail: stefan@spaennare.se
//
// Home page of the author: 
// http://www.spaennare.se/index.html
//
// The image and this pov-file are available on the web-page:
// http://www.spaennare.se/povray.html
//
// This pov-file is free to copy or change if this header appears
// in all copies.
//
// This image is quite "simple" and takes only a few minutes to render
// (at 800 x 600 pixels) on a 1 GHz class computer (or faster).
//
// This pov-file is for POVRAY 3.6 Linux version.
// Use the +mv3.6 option to render with newer versions of POVRAY.
//
// The POVRAY ray-tracing program can be downloaded for free from:
// http://www.povray.org
//
//

// Background by:

// Persistence of Vision Raytracer
// Height field sample
// by Douglas Muir
// Note: Original used 640 x 480 height field.
// This version is scaled down for distribution.
// Requires "fract003.gif" plasma gif for the height field.


#include "shapes.inc"
#include "colors.inc"
#include "textures.inc"

camera {
   location  <0.0, 80.0, -300.0>
   direction <0.0, 0.0, 1.0>
   up        <0.0, 1.0, 0.0>
   right     <4/3, 0.0, 0.0>
   look_at   <0.0, 30.0, 200.0>
}

#declare F_Glass3 =
finish  {
    ambient 0.1
    diffuse 0.1
    reflection 0.1
    refraction 1.0
    ior 1.45
    specular 0.8
    roughness 0.003
    phong 1.0
    phong_size 400.0
}

# declare glass1 = texture {
    pigment { color rgbf <0.98, 0.98, 0.98, 0.90> }
    finish { F_Glass3
//       reflection 0.07
//       ambient 0.1 
//       diffuse 0.1
    }
}

#declare whitetexture = texture {
      pigment { White }
      finish {
         phong 1.0
         phong_size 10.0
         ambient 0.2
         diffuse 0.8
      }
}

#declare blacktexture = texture {
      pigment { Black }
      finish {
         phong 1.0
         phong_size 10.0
         ambient 0.2
         diffuse 0.8
      }
}

#declare sphere1 = sphere {
   <0.0, 0.0, 0.0>, 4.0 
   texture { whitetexture }
}

#declare cube1 = object {
   Cube 
   scale <1.0, 15.5, 1.9>
   translate <0.0, 15.5, 0.0>
   texture { whitetexture }
  
}

#declare cylinder1 = cylinder {
   0.0*y, 5.7*y, 4.1
   texture { whitetexture }
}

#declare cylinder2 = cylinder {
   0.0*y, 0.1*y, 4.1
   texture { blacktexture }
}

#declare cylinder3 = cylinder {
   0.0*y, 0.8*y, 4.1
   texture { whitetexture }
}

#declare cylinder4 = cylinder {
   0.0*y, 2.0*y, 2.7
   texture { whitetexture }
}

#declare cone1 = union {
   intersection {
      object { QCone_Y 
         scale <12.25, -36.825, 12.25>
         translate <0.0, 36.825, 0.0>
      }
      plane { <0, 1, 0>, 0.0 inverse }
      plane { <0, 1, 0>, 24.5 }
   }
   texture { whitetexture }
}

#declare cone2 = union {
   intersection {
      object { QCone_Y 
         scale <4.1, -3.0, 4.1>
         translate <0.0, 3.0, 0.0>
      }
      plane { <0, 1, 0>, 0.0 inverse }
      plane { <0, 1, 0>, 2.0 }
   }
   texture { whitetexture }
}

#declare tc1 = cylinder {
   0.0*y, 4.0*y, 1.75
   texture { whitetexture }
}

#declare tc2 = cylinder {
   0.0*y, 0.5*y, 2.0
   texture { whitetexture }
}

#declare lens1 = cylinder {
   0.0*y, 0.5*y, 1.65
   texture { glass1 }
}

#declare tc3 = cylinder {
   0.0*y, 0.5*y, 1.65
   texture { blacktexture }
}

#declare tube = union {
   object { tc1
   }
   object { tc2
      translate <0.0, 3.5, 0.0>
   }
   object { lens1
      translate <0.0, 3.6, 0.0>
   }
   object { tc3
      translate <0.0, 3.2, 0.0>
   }
}
    

union {
   object { cone1
      translate <0.0, 0.0, 0.0>
   }
   object { cylinder1
      translate <0.0, 24.3, 0.0>
   }
   object { cylinder2
      translate <0.0, 30.0, 0.0>
   }
   object { cylinder3
      translate <0.0, 30.1, 0.0>
   }
   object { cylinder4
      translate <0.0, 30.7, 0.0>
   }
   object { cone2
      translate <0.0, 30.7, 0.0>
   }
   object { sphere1
      translate <0.0, 35.0, 0.0>
   }
   object { tube 
      rotate <0.0, 0.0, 81.0>
      translate <-2.766, 0.438, 0.0>
      rotate <0.0, 45.0, 0.0>
      translate <0.0, 35.0, 0.0>
   }
   object { cube1 
       rotate -17.5*z
       translate <-12.25, 0.0, 0.0>
   }
   translate <12.0, 43.0, -245.0>
}


height_field {
   gif "fract003.gif" 
   water_level 0.4

   pigment {
      image_map { gif "fract003.gif" }
      quick_color White
      rotate 90.0*x
      scale <320.0, 1.0, 200.0>
      translate <0.0, 0.0, -1.0>
   }

   scale <320, 256, 200>
   scale <2.0, 0.5, 2.0>
   translate <-160.0, -63.5, -100.0>
   rotate 10.0*y
   translate <-80.0, 0.0, -30.0>
}

// Define the ocean surface 
plane { y, -10.0
   pigment { Aquamarine }
   normal {
      waves 0.06
      frequency 5000.0
      scale 1000.0
   }
   finish {
      ambient 0.1
      diffuse 0.1
      reflection 0.8
   }
}

// Put a floor underneath to catch any errant waves from the ripples 
plane { y, -11.0
   pigment { colour red 1.0 green 0.6 }
   finish {
      crand 0.05
      ambient 0.8
      diffuse 0.0
   }
}

// Now draw the sky 
sphere { <0.0, 0.0, 0.0>, 3500.0
   pigment {
      onion
      colour_map {
         [0.0 0.6  colour red 1.0 green 0.6 blue 0.0
                   colour red 0.3 green 0.6 blue 0.6]
         [0.6 1.0  colour red 0.3 green 0.6 blue 0.6
                   colour red 0.1 green 0.4 blue 0.6]
      }
      quick_colour red 0.7 green 0.7 blue 1.0
      scale <6000.0, 1700.0, 4000.0>
      translate <-1200.0, 220.0, 2500.0>
   }
   finish {
      ambient 0.8
      diffuse 0.0   /* we don't want clouds casting shadows on the sky */
   }
}


// Put in a few clouds 
plane { y, 300.0
   pigment {
      bozo
      turbulence 0.5
      colour_map {
         [0.0 0.6   colour red 1.0 green 1.0 blue 1.0 filter 1.0
                    colour red 1.0 green 1.0 blue 1.0 filter 1.0]
         [0.6 0.8   colour red 1.0 green 1.0 blue 1.0 filter 1.0
                    colour red 1.0 green 0.8 blue 0.1]
         [0.8 1.001 colour red 1.0 green 0.8 blue 0.1
                    colour red 0.8 green 0.4 blue 0.2]
      }
      quick_colour red 0.7 green 0.7 blue 1.0
      scale <1000.0, 200.0, 800.0>
   }
   finish {
      ambient 0.7
      diffuse 0.0
   }

   translate -450*x
   rotate 6*y
}

// Now to cast some light on the subject 

// light_source { <-50.0, 250.0, -400.0> colour red 0.8 green 0.8 blue 0.533 }

light_source { <-50.0, 250.0, -400.0> colour red 0.48 green 0.48 blue 0.3198 }

// Now to cast some more light on the subject 

light_source {
//   <0, 0, 0> colour red 0.8 green 0.8 blue 0.533
   <0, 0, 0> colour red 0.48 green 0.48 blue 0.3198
   looks_like {
      sphere { <0.0, 0.0, 0.0>, 190.0
         pigment { colour red 1.0 green 0.5 filter 0.35 }
         finish { ambient 1.0 diffuse 0.0 }
      }
   }
       
   translate <-1300.0, 380.0, 2500.0>
}
