//
//
// Pov-file for the POVRAY ray-tracing program 
// ===========================================
//
// Made when: 2010-03-19; Updated 2010-03-27
//
// By Stefan Spaennare, Lund, Sweden
//
// E-mail: stefan@spaennare.se
//
// Home page of the author: 
// http://www.spaennare.se/index.html
//
// The image and this pov-file are available on the web-page:
// http://www.spaennare.se/povray.html
//
// This pov-file is free to copy or change if this header appears
// in all copies.
//
// This image is quite "simple" and takes only a few minutes to render
// (at 800 x 600 pixels) on a 1 GHz class computer (or faster).
//
// This pov-file is for POVRAY 3.6 Linux version.
// Use the +mv3.6 option to render with newer versions of POVRAY.
//
// The POVRAY ray-tracing program can be downloaded for free from:
// http://www.povray.org
//
//
  
  

#include "colors.inc"           
// #include "textures.inc"       
#include "shapes.inc"
#include "glass.inc"
#include "woods.inc" 
#include "golds.inc"
#include "colors.inc"
#include "shapes.inc" 


camera {
   location <0.0, 2.8, -8.3>
   up       <0.0, 1.0, 0.0>
   right    <4/3, 0.0, 0.0>
   look_at  <0.0, 0.0, 0.0>
}


light_source { <5.0, 8.0, -40.0> color rgb 0.40 }

light_source { <-5.0, 8.0, -40.0> color rgb 0.40 } 

light_source { <0.0, 30.0, -40.0> color rgb 0.40 }

sky_sphere { pigment { rgb <0.7,0.7,0.7> } }

 

#declare texture1 = texture {     
      pigment {
         checker color rgb <0.4, 0.4, 0.6> color rgb 0.8 
         scale 4.0
      }
      finish {
         phong 0.2
	 phong_size 1.0
         ambient 0.8
         diffuse 0.2
      }      
}


#declare wood1 = texture {
   T_Wood11   
    scale 1.0
}        

#declare wood2 = texture {
   T_Wood11   
    scale 2.0
}

#declare wood3 = texture {
   T_Wood11     
    scale 1.0
    rotate 90*z
    rotate 90*x 
    translate <-0.0, 0.0, -10.0>
}  
    

plane {z, 4.0 inverse
   texture {
      pigment { color rgb <0.8, 0.78, 0.7> }
      finish {
         phong 0.0
         phong_size 1.0
         ambient 0.8
         diffuse 0.2 
      }
   }
}   


plane {y, -0.505
    texture { wood2 }
    scale 3.0
}

       
       
#declare temp1 = object {                   
   union {                  
      plane { x, 0.0  
         rotate 7.0*z
         rotate 30.5*y   
      }     
      plane { x, 0.0 inverse 
         rotate -7.0*z
         rotate -30.5*y
      }           
   }                                       
}        


#declare ellips1 = object {
   union {
      intersection {
         object { Ellipsoid
            scale <0.65, 0.90, 0.65>
         }
         object { Ellipsoid
            scale <0.53, 0.8, 0.53>
            translate <0.0, 0.2, 0.0>
            inverse
          }
          plane { y, 0.25 }
          object { temp1 
             rotate 0*y
          }  
          object { temp1 
             rotate 72*y
          }   
          object { temp1 
             rotate 144*y
          } 
          object { temp1 
             rotate 216*y
          }
          object { temp1 
             rotate 288*y
          }
       }     
    }
    texture { wood3 }
}  


#declare cone1 = union {
   intersection {
      object { QCone_Y 
         scale <0.11, 0.8, 0.11>
         translate <0.0, 2.2, 0.0>
      }
      plane { y, 0.0 inverse }
      plane { y, 0.6 }
   } 
   texture { wood3 }  
}                     


#declare cone2 = union {  
   intersection {
      object { QCone_Y
         scale <1.34, 0.10, 1.34>  
      }
      plane { y, 0.0 inverse } 
      plane { y, 0.1 } 
   }   
   texture { wood3 }
}    


#declare cone3 = union {  
   intersection {
      object { QCone_Y
         scale <1.34, 0.10, 1.34> 
      }
      plane { y, 0.0 inverse } 
      plane { y, 0.1 } 
   }    
   texture {T_Gold_3C}
}

 
#declare cyl1 = union {
    intersection {
       cylinder { -0.07*y, 0.07*y, 1.34 } 
       cylinder { -0.08*y, 0.08*y, 0.44 inverse }  
       object {cone2 inverse
          translate <0.0, -0.026, 0.0>
       }
    }             
    texture { wood3 }      
}  
     

#declare cyl2 = union {
    intersection {
       cylinder { -0.26*y, -0.06*y, 0.44 } 
       cylinder { -0.27*y, -0.061*y, 0.42 inverse }  
     }  
     intersection {
       cylinder { -0.06*y, 0.09*y, 0.68 } 
       cylinder { -0.061*y, 0.091*y, 0.42 inverse } 
       object {cone3 inverse
           translate <0.0, -0.002, 0.0>
        } 
     }
     cylinder { -0.28*y, -0.26*y, 0.42 }
     torus {0.68, 0.02
         translate <0.0, 0.03, 0.0>
      }   
      torus {0.42, 0.02 
         translate <0.0, -0.26, 0.0>
      }
      texture { T_Gold_3C }                      
} 


#declare box1 = union {
    box { <-1.0, -0.01, -1.5> <1.0, 0.01, 1.5> } 
      texture { texture1 
      scale 0.01
    }    
}


union {
   object { ellips1                
      scale <2.0, 2.0, 2.0>
      translate <0.0, 1.0, 0.0>
   }   
   object { cone1                
      scale <2.4, 2.0, 2.4>
      translate <0.0, -1.9, 0.15>
   }        
   object { cyl1                
      scale <1.0, 1.0, 1.0>
      translate <0.0, 1.57, -0.0>
   }  
   object { cyl2                
      scale <1.0, 1.0, 1.0>
      translate <0.0, 1.57, -0.0> 
   }                      
   rotate -4*y  
   translate <0.0, 0.25, -2.7>
}


object { box1
   scale <3.0, 1.0, 3.0> 
   translate <0.0, -1.5, -2.7>
}

