//
//
// Pov-file for the POVRAY ray-tracing program 
// ===========================================
//
// Made when: Sometimes during the time 1994 - 1997, updated September 2005
//
// By Stefan Spaennare, Lund, Sweden
//
// E-mail: stefan@spaennare.se
//
// Home page of the author: 
// http://www.spaennare.se/index.html
//
// The image and this pov-file are available on the web-page:
// http://www.spaennare.se/povray.html
//
// This pov-file is free to copy or change if this header appears
// in all copies.
//
// This image is quite "simple" and takes only a few minutes to render
// (at 800 x 600 pixels) on a 1 GHz class computer (or faster).
//
// This pov-file is for POVRAY 3.6 Linux version.
// Use the +mv3.6 option to render with newer versions of POVRAY.
//
// The POVRAY ray-tracing program can be downloaded for free from:
// http://www.povray.org
//
//


#include "colors.inc"
#include "shapes.inc"

camera {
   location <0, 2.0, -10>
   up       <0.0, 1.0, 0.0>
   right    <4/3, 0.0, 0.0>
   look_at  <0, 0, 0>
}

// light_source { <0, 0, -40> color rgb 0.18}

// light_source { <0 40, -20> color rgb 0.34}

light_source { <2.0, 0.0, -40.0> color rgb 0.30}

light_source { <-2.0, 40.0, -20.0> color rgb 0.30}

sky_sphere {pigment {rgb <0.61, 0.70, 0.85>} }

// sky_sphere {pigment {rgb <0.7, 0.7, 0.7>} }

// sky_sphere {pigment {rgb <0.45, 0.75, 1.0>} }

// sky_sphere {pigment {rgb <0.27, 0.45, 0.60>} }

// sphere { <0,0,0>, 1000 hollow texture { pigment {rgb <0.45, 0.75, 1.0>} } }


#declare steeltexture = texture {
// pigment { color red 0.5 green 0.5 blue 0.5 }
   pigment { color red 0.5 green 0.45 blue 0.35 }
   finish {
      ambient 0.035
      reflection 0.4
      diffuse 1.0
      phong 1.0
      phong_size 3.0
   }
}

plane {z, 12.0 inverse
   texture {
      pigment { color rgb 0.9 }
      finish {
         phong 0.0
         phong_size 1.0
         ambient 0.8
         diffuse 0.2 
      }
   }
}

plane {y, -2.96985 
   texture {
      pigment {
         checker color rgb 0.8 color Yellow 
         scale 2.0
      }
      finish {
         phong 0.2
	 phong_size 1.0
         ambient 0.8
         diffuse 0.2
      }
   }
   scale 1.0 
}


#declare cylb1 = intersection {
   cylinder { -0.05*z, 0.05*z, 3.4 }
   cylinder { -0.05*z, 0.05*z, 3.1 open inverse }
} // End intersection 


#declare cylb2 = intersection {
   cylinder { -0.05*z, 0.05*z, 1.9 }
   cylinder { -0.05*z, 0.05*z, 1.6 open inverse }
} // End intersection 


#declare b1 =  union {

   intersection {

      cylinder { -0.6*z, 0.6*z, 3.5 }
      cylinder { -0.6*z, 0.6*z, 3.0 open inverse }

      torus {2.5, 0.7
         rotate 90.0*x
         inverse
      }

   } // end intersection

   object { cylb1 
      translate 0.65*z
   }
   object { cylb1 
      translate -0.65*z
   }

   torus {3.40, 0.10
      rotate 90.0*x
      translate 0.60*z
   }
   torus {3.40, 0.10
      rotate 90.0*x
      translate -0.60*z
   }

   torus {3.10, 0.10
      rotate 90.0*x
      translate 0.60*z
   }
   torus {3.10, 0.10
      rotate 90.0*x
      translate -0.60*z
   }

} // End union (b1)


#declare b2 =  union {

   intersection {

      cylinder { -0.6*z, 0.6*z, 2.0 }
      cylinder { -0.6*z, 0.6*z, 1.5 open inverse }

      torus {2.5, 0.7
         rotate 90.0*x
         inverse
      }

   } // end intersection

   object { cylb2 
      translate 0.65*z
   }
   object { cylb2 
      translate -0.65*z
   }

   torus {1.90, 0.10
      rotate 90.0*x
      translate 0.60*z
   }
   torus {1.90, 0.10
      rotate 90.0*x
      translate -0.60*z
   }

   torus {1.60, 0.10
      rotate 90.0*x
      translate 0.60*z
   }
   torus {1.60, 0.10
      rotate 90.0*x
      translate -0.60*z
   }

} // End union (b2)


#declare b3 = union {

   sphere { 2.5*y, 0.7
//    rotate 0.0*z
   }
   sphere { 2.5*y, 0.7
      rotate 60.0*z
   }
   sphere { 2.5*y, 0.7
      rotate 120.0*z
   }
   sphere { 2.5*y, 0.7
      rotate 180.0*z
   }
   sphere { 2.5*y, 0.7
      rotate 240.0*z
   }
   sphere { 2.5*y, 0.7
      rotate 300.0*z
   }

} // End union (b3)


# declare bearing1 = union {

   object { b1 }
   object { b2 }
   object { b3 
//    rotate 0.0*z
//    rotate 25.0*z
   }
   texture { steeltexture }

} // End union (bearing1)


# declare bearing2 = union {

   object { b1 }
   object { b2 }
   object { b3 
//    rotate 0.0*z
//    rotate 25.0*z
   }
   texture { steeltexture }

} // End union (bearing2)


union {

   object { bearing1
      translate <1.25, 0.0, 0.0>
//    translate <1.225, 0.0, 0.0>
   }
   object { bearing2
      rotate 90.0*x
      translate <-1.25, 0.0, 0.0>
//    translate <-1.225, 0.0, 0.0>
   }
   rotate 45.0*x

} // End union
