//
//
// Pov-file for the POVRAY ray-tracing program 
// ===========================================
//
// Made when: April 2005, updated September 2005
//
// By Stefan Spaennare, Lund, Sweden
//
// E-mail: stefan@spaennare.se
//
// Home page of the author: 
// http://www.spaennare.se/index.html
//
// The image and this pov-file are available on the web-page:
// http://www.spaennare.se/povray.html
//
// This pov-file is free to copy or change if this header appears
// in all copies.
//
// This image is quite "simple" and takes only a few minutes to render
// (at 800 x 600 pixels) on a 1 GHz class computer (or faster).
//
// This pov-file is for POVRAY 3.6 Linux version.
// Use the +mv3.6 option to render with newer versions of POVRAY.
//
// The POVRAY ray-tracing program can be downloaded for free from:
// http://www.povray.org
//
//


#include "colors.inc"
#include "shapes.inc"

camera {
   location <0, 2.0, -10>
   up       <0.0, 1.0, 0.0>
   right    <4/3, 0.0, 0.0>
   look_at  <0, 0, 0>
}

light_source { <5.0, 8.0, -40.0> color rgb 0.12}

light_source { <5.0, 44.0, -20.0> color rgb 0.12}

sky_sphere {pigment {rgb <0.7,0.7,0.7>} }

// sphere { <0,0,0>, 1000 hollow texture { pigment {rgb <0.9, 0.9, 0.9>} } }

#declare colfinish = finish {
   phong 1.0
   phong_size 10.0
   ambient 0.07
   diffuse 3.5 
}

#declare redtexture = texture {
   pigment { Red }
   finish { colfinish }
}

#declare greentexture = texture {
   pigment { Green }
   finish { colfinish }
}

#declare bluetexture = texture {
   pigment { Blue }
   finish { colfinish }
}

plane {z, 12.0 inverse
   texture {
      pigment { color rgb 0.9 }
      finish {
         phong 0.0
         phong_size 1.0
         ambient 0.8
         diffuse 0.2 
      }
   }
}

plane {y, -3.0 
   texture {
      pigment {
         checker color rgb 0.8 color rgb 1.0 
         scale 2.0
      }
      finish {
         phong 0.2
	 phong_size 1.0
         ambient 0.8
         diffuse 0.2
      }
   }
   scale 1.0 
}

#declare l1 = cylinder {
   -2.0*z, 2.0*z, 1.0 
}

#declare l2 = intersection {
   torus { 2.0, 1.0 }
   plane { 1.0*z, 0.0 inverse }
}

#declare link0 = union {
   object { l1 
      translate -2.0*x
   }
   object { l1 
      translate 2.0*x
   }
   object { l2 
      translate 2.0*z
   }
   object { l2 
      translate 2.0*z
      rotate 180*x
   }
}

#declare linkr = object {
   link0 
   texture { redtexture }
}

#declare linkg = object {
   link0 
   texture { greentexture }
}

#declare linkb = object {
   link0 
   texture { bluetexture }
}

union {
   object { linkb 
   }
   object { linkg 
      rotate 90.0*z
      rotate 90.0*x
   }
   object { linkr 
      rotate 90.0*y
      rotate 90.0*x
   }
   scale 0.7
   rotate -45.0*z
   rotate 45.0*y
   rotate -15.0*z
   rotate -10.0*y
   rotate 2.0*x
}
